@@ -1,23 +1,29 @@
 /*
  * Cogl
  *
- * An object oriented GL/GLES Abstraction/Utility Layer
+ * A Low Level GPU Graphics and Utilities API
  *
  * Copyright (C) 2011 Intel Corporation.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * Permission is hereby granted, free of charge, to any person
+ * obtaining a copy of this software and associated documentation
+ * files (the "Software"), to deal in the Software without
+ * restriction, including without limitation the rights to use, copy,
+ * modify, merge, publish, distribute, sublicense, and/or sell copies
+ * of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * The above copyright notice and this permission notice shall be
+ * included in all copies or substantial portions of the Software.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see
- * <http://www.gnu.org/licenses/>.
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
+ * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
+ * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
+ * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+ * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+ * SOFTWARE.
  *
  *
  * Authors:
@@ -63,6 +69,7 @@ static const CoglWinsysVtable *parent_vtable;
 typedef struct _CoglRendererKMS
 {
   int fd;
+  int opened_fd;
   struct gbm_device *gbm;
   CoglClosure *swap_notify_idle;
 } CoglRendererKMS;
@@ -115,6 +122,9 @@ _cogl_winsys_renderer_disconnect (CoglRenderer *renderer)
 
   eglTerminate (egl_renderer->edpy);
 
+  if (kms_renderer->opened_fd >= 0)
+    close (kms_renderer->opened_fd);
+
   g_slice_free (CoglRendererKMS, kms_renderer);
   g_slice_free (CoglRendererEGL, egl_renderer);
 }
@@ -279,14 +289,25 @@ _cogl_winsys_renderer_connect (CoglRenderer *renderer,
    * we're doing here... */
   g_setenv ("EGL_PLATFORM", "drm", 1);
 
-  kms_renderer->fd = open (device_name, O_RDWR);
-  if (kms_renderer->fd < 0)
+  kms_renderer->fd = -1;
+  kms_renderer->opened_fd = -1;
+
+  if (renderer->kms_fd >= 0)
     {
-      /* Probably permissions error */
-      _cogl_set_error (error, COGL_WINSYS_ERROR,
-                   COGL_WINSYS_ERROR_INIT,
-                   "Couldn't open %s", device_name);
-      return FALSE;
+      kms_renderer->fd = renderer->kms_fd;
+    }
+  else
+    {
+      kms_renderer->opened_fd = open (device_name, O_RDWR);
+      kms_renderer->fd = kms_renderer->opened_fd;
+      if (kms_renderer->fd < 0)
+        {
+          /* Probably permissions error */
+          _cogl_set_error (error, COGL_WINSYS_ERROR,
+                           COGL_WINSYS_ERROR_INIT,
+                           "Couldn't open %s", device_name);
+          return FALSE;
+        }
     }
 
   kms_renderer->gbm = gbm_create_device (kms_renderer->fd);
@@ -324,7 +345,8 @@ egl_terminate:
 destroy_gbm_device:
   gbm_device_destroy (kms_renderer->gbm);
 close_fd:
-  close (kms_renderer->fd);
+  if (kms_renderer->opened_fd >= 0)
+    close (kms_renderer->opened_fd);
 
   _cogl_winsys_renderer_disconnect (renderer);
 
@@ -768,7 +790,7 @@ _cogl_winsys_egl_context_created (CoglDisplay *display,
   egl_display->dummy_surface =
     eglCreateWindowSurface (egl_renderer->edpy,
                             egl_display->egl_config,
-                            (NativeWindowType) kms_display->dummy_gbm_surface,
+                            (EGLNativeWindowType) kms_display->dummy_gbm_surface,
                             NULL);
   if (egl_display->dummy_surface == EGL_NO_SURFACE)
     {
@@ -964,7 +986,7 @@ _cogl_winsys_onscreen_init (CoglOnscreen *onscreen,
   egl_onscreen->egl_surface =
     eglCreateWindowSurface (egl_renderer->edpy,
                             egl_display->egl_config,
-                            (NativeWindowType) kms_onscreen->surface,
+                            (EGLNativeWindowType) kms_onscreen->surface,
                             NULL);
   if (egl_onscreen->egl_surface == EGL_NO_SURFACE)
     {
@@ -1069,6 +1091,17 @@ _cogl_winsys_egl_kms_get_vtable (void)
   return &vtable;
 }
 
+void
+cogl_kms_renderer_set_kms_fd (CoglRenderer *renderer,
+                              int fd)
+{
+  _COGL_RETURN_IF_FAIL (cogl_is_renderer (renderer));
+  /* NB: Renderers are considered immutable once connected */
+  _COGL_RETURN_IF_FAIL (!renderer->connected);
+
+  renderer->kms_fd = fd;
+}
+
 int
 cogl_kms_renderer_get_kms_fd (CoglRenderer *renderer)
 {
@@ -1139,7 +1172,7 @@ cogl_kms_display_set_layout (CoglDisplay *display,
       new_egl_surface =
         eglCreateWindowSurface (egl_renderer->edpy,
                                 egl_display->egl_config,
-                                (NativeWindowType) new_surface,
+                                (EGLNativeWindowType) new_surface,
                                 NULL);
       if (new_egl_surface == EGL_NO_SURFACE)
         {
